OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive til mappen \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Dette kan normalt rettes ved at give webserveren skriveadgang til config folderen.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Men hvis du foretrækker at bibeholde config.php skrivebeskyttet, så sæt parameter \"config_is_read_only\" til true i filen. ",
    "See %s" : "Se %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Applikationen %1$s er ikke til stede eller har en ikke-kompatibel version med denne server. Tjek venligst apps mappen.",
    "Sample configuration detected" : "Eksempel for konfiguration registreret",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Der er registreret at konfigurations eksemplet er blevet kopieret direkte. Dette kan ødelægge din installation og understøttes ikke. Læs venligst dokumentationen før der foretages ændringer i config.php",
    "The page could not be found on the server." : "Siden kunne ikke findes på serveren.",
    "%s email verification" : "%s email verifikation",
    "Email verification" : "Email verifikation",
    "Click the following button to confirm your email." : "Tryk på følgende knap for at bekræfte din email.",
    "Click the following link to confirm your email." : "Klik på følgende link for at bekræfte din email.",
    "Confirm your email" : "Bekræft din email",
    "Other activities" : "Andre aktiviteter",
    "%1$s and %2$s" : "%1$s og %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
    "Education bundle" : "Uddannelsespakke",
    "Enterprise bundle" : "Enterprise version",
    "Groupware bundle" : "Groupware version",
    "Hub bundle" : "Hub version",
    "Public sector bundle" : "Offentlig sektor pakke",
    "Social sharing bundle" : "SoMe delings version",
    "PHP %s or higher is required." : "Der kræves PHP %s eller nyere.",
    "PHP with a version lower than %s is required." : "Der kræves PHP %s eller ældre.",
    "%sbit or higher PHP required." : "Der kræves PHP %s eller nyere.",
    "The following architectures are supported: %s" : "Følgende arkitekturer er understøttes: %s",
    "The following databases are supported: %s" : "Følgende databaser understøttes: %s",
    "The command line tool %s could not be found" : "Kommandolinjeværktøjet %s blev ikke fundet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgængeligt.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Der kræves en version af biblioteket %1$s, der er højere end %2$s - tilgængelig version er %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Der kræves en version af biblioteket %1$s, der er lavere end %2$s - tilgængelig version er %3$s.",
    "The following platforms are supported: %s" : "Følgende platforme understøttes: %s",
    "Server version %s or higher is required." : "Du skal have server version %s eller nyere.",
    "Server version %s or lower is required." : "Du skal have server version %s eller ældre.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "En konto, der er logget på, skal være administrator, underadministrator eller have en særlig rettighed for at få adgang til denne indstilling",
    "Your current IP address doesn't allow you to perform admin actions" : "Din nuværende IP-adresse tillader dig ikke at udføre administratorhandlinger",
    "Logged in account must be an admin or sub admin" : "Kontoen, der er logget på, skal være en administrator eller underadministrator",
    "Logged in account must be an admin" : "Kontoen, der er logget på, skal være en admin",
    "Wiping of device %s has started" : "Komplet sletning af enhed %s er påbegyndt",
    "Wiping of device »%s« has started" : "Komplet sletning af enhed »%s« er påbegyndt",
    "»%s« started remote wipe" : "Fjernsletning påbegyndt af »%s« ",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Enheden eller applikationen  »%s« har påbegyndt en fjernsletnings proces. Du vil modtage en e-mail når processen er færdig",
    "Wiping of device %s has finished" : "Komplet sletning af enhed %s er færdig",
    "Wiping of device »%s« has finished" : "Komplet sletning af enhed »%s« er færdig",
    "»%s« finished remote wipe" : "»%s« er færdig med fjernsletning",
    "Device or application »%s« has finished the remote wipe process." : " Fjernsletningen der blev aktiveret af enhed alle applikation »%s« er færdig.",
    "Remote wipe started" : "Fjernsletning er startet",
    "A remote wipe was started on device %s" : "En fjernsletning af enheden %s er påbegyndt",
    "Remote wipe finished" : "Fjernsletning er færdig",
    "The remote wipe on %s has finished" : "Fjernsletningen af %s er færdig",
    "Authentication" : "Godkendelse",
    "Unknown filetype" : "Ukendt filtype",
    "Invalid image" : "Ugyldigt billede",
    "Avatar image is not square" : "Avatar billedet er ikke kvadratisk",
    "Files" : "Filer",
    "View profile" : "Vis profil",
    "same time" : "samme tid",
    "_%nh_::_%nh_" : ["%nt","%nt"],
    "_%nm_::_%nm_" : ["%nm","%nm"],
    "%s ahead" : "%s foran",
    "%s behind" : "%s bagud",
    "Local time: %s" : "Lokal tid: %s",
    "today" : "i dag",
    "tomorrow" : "i morgen",
    "yesterday" : "i går",
    "_in %n day_::_in %n days_" : ["om %n dag","om %n dage"],
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dage siden"],
    "next month" : "næste måned",
    "last month" : "sidste måned",
    "_in %n month_::_in %n months_" : ["om %n måned","om %n måneder"],
    "_%n month ago_::_%n months ago_" : ["%n måned siden","%n måneder siden"],
    "next year" : "næste år",
    "last year" : "sidste år",
    "_in %n year_::_in %n years_" : ["om %n år","om %n år"],
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_in %n hour_::_in %n hours_" : ["om %n time","om %n timer"],
    "_%n hour ago_::_%n hours ago_" : ["%n time siden","%n timer siden"],
    "_in %n minute_::_in %n minutes_" : ["om %n minut","om %n minutter"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut siden","%n minutter siden"],
    "in a few seconds" : "om få sekunder",
    "seconds ago" : "få sekunder siden",
    "Empty file" : "Tom fil",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulet med ID: %s eksisterer ikke. Aktiver det venligst i dine indstillinger eller kontakt din administrator.",
    "No file conversion providers available" : "Ingen filkonverteringsudbydere tilgængelige",
    "File is too large to convert" : "Filen er for stor til at konvertere",
    "Destination does not match conversion extension" : "Destinationen matcher ikke konverteringsudvidelsen",
    "Could not convert file" : "Kunne ikke konvertere filen",
    "Destination does not exist" : "Placeringen findes ikke",
    "Destination is not creatable" : "Placeringen kan ikke oprettes",
    "Dot files are not allowed" : "Filer med punktummer er ikke tilladt",
    "\"%1$s\" is a forbidden file or folder name." : "\" %1$s\" er et forbudt fil- eller mappenavn.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\" %1$s\" er et forbudt præfiks for fil- eller mappenavne.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\" %1$s\" er ikke tilladt inde i et fil- eller mappenavn.",
    "\"%1$s\" is a forbidden file type." : "\" %1$s\" er en forbudt filtype.",
    "Filenames must not end with \"%1$s\"." : "Filnavne må ikke ende på \"%1$s\".",
    "Invalid parent path" : "Ugyldig overordnet sti",
    "File already exists" : "Filen findes allerede",
    "Invalid path" : "Ugyldig sti",
    "Failed to create file from template" : "Fejl ved oprettelse af fil fra skabelon",
    "Templates" : "Skabeloner",
    "Storage %s cannot be moved" : "Lager %s kan ikke flyttes",
    "Moving a share (%s) into a shared folder is not allowed" : "Flytning af en deling (%s) til en delt mappe er ikke tilladt",
    "Moving a storage (%s) into a shared folder is not allowed" : "Flytning af et lager (%s) til en delt mappe er ikke tilladt",
    "Moving a share (%s) into another share (%s) is not allowed" : "Flytning af en deling (%s) til en anden deling (%s) er ikke tilladt",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Flytning af en deling (%s) til et andet lager (%s) er ikke tilladt",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Flytning af et lager (%s) til en deling (%s) er ikke tilladt",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Flytning af et lager (%s) til et andet lager (%s) er ikke tilladt",
    "Path contains invalid segments" : "Sti indeholder ugyldige segmenter",
    "Filename is a reserved word" : "Filnavn er et reserveret ord",
    "Filename contains at least one invalid character" : "Filnavnet indeholder mindst et ugyldigt tegn",
    "Filename is too long" : "Filnavn er for langt",
    "Empty filename is not allowed" : "Tomme filnavne er ikke tilladt",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan ikke installeres fordi appinfo filen ikke kan læses.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan ikke installeres fordi den ikke er kompatibel med denne version af serveren.",
    "__language_name__" : "Dansk",
    "This is an automatically sent email, please do not reply." : "Dette er en automatisk sendt e-mail, svar venligst ikke.",
    "Help & privacy" : "Hjælp & privatliv",
    "Appearance and accessibility" : "Udseende og tilgængelighed",
    "Apps" : "Apps",
    "Personal settings" : "Personlige indstillinger",
    "Administration settings" : "Systemindstillinger",
    "Settings" : "Indstillinger",
    "Log out" : "Log ud",
    "Accounts" : "Konti",
    "Email" : "E-mail",
    "Mail %s" : "Mail %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Vis %s på fediverset",
    "Phone" : "Telefon",
    "Call %s" : "Ring op %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Følg %s på Twitter",
    "Website" : "Hjemmeside",
    "Visit %s" : "Besøg %s",
    "Address" : "Adresse",
    "Profile picture" : "Profilbillede",
    "About" : "Om",
    "Display name" : "Vist navn",
    "Headline" : "Overskrift",
    "Organisation" : "Organisation",
    "Role" : "Rolle",
    "Pronouns" : "Pronominer",
    "Unknown account" : "Ukendt konto",
    "Additional settings" : "Yderligere indstillinger",
    "Enter the database Login and name for %s" : "Indtast database Login og navn for %s",
    "Enter the database Login for %s" : "Indtast database Login for %s",
    "Enter the database name for %s" : "Indtast databasenavnet for %s",
    "You cannot use dots in the database name %s" : "Du må ikke bruge punktummer i databasenavnet %s",
    "MySQL Login and/or password not valid" : "MySQL login og/eller adgangskode ikke ikke gyldig",
    "You need to enter details of an existing account." : "Du skal indtaste detaljerne for en eksisterende konto.",
    "Oracle connection could not be established" : "Oracle forbindelsen kunne ikke etableres",
    "Oracle Login and/or password not valid" : "Oracle login og / eller adgangskode ikke gyldig",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL login og / eller adgangskode ikke gyldig",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X understøttes ikke, og %s vil ikke fungere korrekt på denne platform. Brug det på eget ansvar!",
    "For the best results, please consider using a GNU/Linux server instead." : "For de bedste resultater, overvej venligst at bruge en GNU/Linux-server i stedet.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at open_basedir er blevet konfigureret gennem php.ini. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern venligst indstillingen for open_basedir inde i din php.ini eller skift til 64-bit PHP.",
    "Set an admin Login." : "Sæt et admin login.",
    "Set an admin password." : "Angiv et admin kodeord.",
    "Cannot create or write into the data directory %s" : "Kan ikke oprette eller skrive ind i datamappen %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delingsbackend'en %s skal implementere grænsefladen OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delingsbackend'en %s blev ikke fundet",
    "Sharing backend for %s not found" : "Delingsbackend'en for %s blev ikke fundet",
    "%1$s shared %2$s with you" : " %1$s delte %2$s med dig",
    "Open %s" : "Åbn %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you and wants to add:" : " %1$s delte %2$s med dig og ønsker at tilføje:",
    "%1$s shared %2$s with you and wants to add" : " %1$s delte %2$s med dig og ønsker at tilføje",
    "%s added a note to a file shared with you" : "%s tilføjede en note til en fil delt med dig",
    "Passwords are enforced for link and mail shares" : "Adgangskoder gennemtvinges for link og mail delinger",
    "Share recipient is not a valid user" : "Delingsmodtager er ikke en gyldig bruger",
    "Share recipient is not a valid group" : "Delingsmodtager er ikke en gyldig gruppe",
    "Share recipient should be empty" : "Delingsmodtager skal være tom",
    "Share recipient should not be empty" : "Delingsmodtager bør ikke være tom",
    "Share recipient is not a valid circle" : "Delingsmodtager er ikke en gyldig cirkel",
    "Unknown share type" : "Ukendt deletype",
    "Share initiator must be set" : "Delingsstarteren skal angives",
    "Cannot share with yourself" : "Kan ikke dele med dig selv",
    "Shared path must be set" : "Delingssti skal indstilles",
    "Shared path must be either a file or a folder" : "Delt sti skal enten være en fil eller en mappe",
    "You cannot share your root folder" : "Du kan ikke dele din rodmappe",
    "You are not allowed to share %s" : "Du har ikke tilladelse til at dele %s",
    "Valid permissions are required for sharing" : "Gyldige tilladelser er nødvendige for deling",
    "File shares cannot have create or delete permissions" : "Fildelinger kan ikke have oprettelses- eller sletningsrettigheder",
    "Cannot increase permissions of %s" : "Kan give yderigere rettigheder til %s",
    "Shares need at least read permissions" : "Deling skal i det mindste have læsetilladelse",
    "Files cannot be shared with delete permissions" : "Filer kan ikke deles med rettigheder til at slette",
    "Files cannot be shared with create permissions" : "Filer kan ikke deles med rettigheder til at oprette",
    "Expiration date is in the past" : "Udløbsdatoen ligger tilbage i tid",
    "Expiration date is enforced" : "Udløbsdato gennemtvinges:",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Udløbsdato kan ikke sættes mere end %n dag ud i fremtiden","Udløbsdato kan ikke sættes mere end %n dage ud i fremtiden"],
    "Sharing is only allowed with group members" : "Deling er kun tilladt med gruppemedlemmer",
    "Sharing %s failed, because this item is already shared with the account %s" : "Deling af %s mislykkedes, fordi dette element allerede er delt med kontoen %s",
    "Group sharing is now allowed" : "Gruppedeling er nu tilladt",
    "Sharing is only allowed within your own groups" : "Deling er kun tilladt i dine egne grupper",
    "Path is already shared with this group" : "Sti deles allerede med denne gruppe",
    "Link sharing is not allowed" : "Link deling er ikke tilladt",
    "Public upload is not allowed" : "Offentlig upload er ikke tilladt",
    "You cannot share a folder that contains other shares" : "Du kan ikke dele en mappe, der indeholder andre delinger",
    "Sharing is disabled" : "Deling er deaktiveret",
    "Sharing is disabled for you" : "Deling er deaktiveret for dig",
    "Cannot share with the share owner" : "Kan ikke dele med delingsejeren",
    "Share does not have a full ID" : "Deling har ikke et fuldt ID",
    "Cannot change share type" : "Kan ikke ændre delingstype",
    "Can only update recipient on user shares" : "Kan kun opdatere modtager på brugerdelinger",
    "Cannot enable sending the password by Talk with an empty password" : "Kan ikke aktivere afsendelse af adgangskode via Snak med en tom adgangskode",
    "Cannot enable sending the password by Talk without setting a new password" : "Kan ikke aktivere afsendelse af adgangskoden via Snak uden at angive en ny adgangskode",
    "Cannot disable sending the password by Talk without setting a new password" : "Kan ikke deaktivere afsendelse af adgangskode via Snak uden at angive en ny adgangskode",
    "Share provider does not support accepting" : "Delingsleverandør understøtter ikke accept",
    "Cannot change target of link share" : "Kan ikke ændre mål for link deling",
    "Invalid share recipient" : "Ugyldig delingsmodtager",
    "Group \"%s\" does not exist" : "Gruppe \"%s\" eksisterer ikke",
    "The requested share does not exist anymore" : "Det delte emne eksisterer ikke længere",
    "The requested share comes from a disabled user" : "Den ønskede deling kommer fra en deaktiveret bruger",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Brugeren blev ikke oprettet, fordi brugergrænsen er nået. Tjek dine notifikationer for at få flere oplysninger.",
    "Could not find category \"%s\"" : "Kunne ikke finde kategorien \"%s\"",
    "Input text" : "Inputtekst",
    "The input text" : "Inputteksten",
    "Sunday" : "Søndag",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sun." : "Søn.",
    "Mon." : "Man.",
    "Tue." : "Tir.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lør.",
    "Su" : "Sø",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lø",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Marts",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "En gyldig adgangskode skal angives",
    "The Login is already being used" : "Login anvendes allerede",
    "Could not create account" : "Kunne ikke oprette konto",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kun følgende tegn er tilladt i et login: \"a-z\", \"A-Z\", \"0-9\", mellemrum og \"_. @ -\"",
    "A valid Login must be provided" : "Et gyldigt login skal angives",
    "Login contains whitespace at the beginning or at the end" : "Login indeholder mellemrum i begyndelsen eller slutningen",
    "Login must not consist of dots only" : "Login må ikke kun bestå af prikker",
    "Login is invalid because files already exist for this user" : "Login er ugyldigt, fordi filer allerede eksisterer for denne bruger",
    "Account disabled" : "Konto deaktiveret",
    "Login canceled by app" : "Login annulleret af app",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan ikke installeres, da følgende afhængigheder ikke imødekommes: %2$s",
    "a safe home for all your data" : "et sikkert hjem til alle dine data",
    "Application is not enabled" : "Programmet er ikke aktiveret",
    "Authentication error" : "Adgangsfejl",
    "Token expired. Please reload page." : "Adgang er udløbet. Genindlæs siden.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen database driver (sqlite, mysql eller postgresql) er installeret.",
    "Cannot write into \"config\" directory." : "Kan ikke skrive til mappen \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen. Se %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Men hvis du foretrækker at bibeholde config.php skrivebeskyttet, så sæt parameter \"config_is_read_only\" til true i filen. Se %s",
    "Cannot write into \"apps\" directory." : "Kan ikke skrive til mappen \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dette kan som regel rettes ved at give webserveren skriveadgang til apps-mappen eller slå appstore fra i config-filen.",
    "Cannot create \"data\" directory." : "Kan ikke oprette mappen \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til rod mappen. Se %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Rettigheder kan som regel rettes ved at give webserveren skriveadgang til rodmappen. Se %s.",
    "Your data directory is not writable." : "Data biblioteket er skrivebeskyttet.",
    "Setting locale to %s failed." : "Angivelse af %s for lokalitet mislykkedes.",
    "Please install one of these locales on your system and restart your web server." : "Installer venligst en af disse lokaliteter på dit system, og genstart din webserver.",
    "PHP module %s not installed." : "PHP-modulet %s er ikke installeret.",
    "Please ask your server administrator to install the module." : "Du bedes anmode din serveradministrator om at installere modulet.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-indstillingen \"%s\" er ikke angivet til \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ændring af denne indstilling i php.ini vil tillade Nextcloud at køre igen",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er angivet til <code>%s</code>, i stedet for den forventede værdi <code>0</code>",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "For at rette dette problem, sæt <code>mbstring.func_overload</code> til <code>0</code> i din php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP er tilsyneladende sat op til at fjerne indlejrede doc-blokke. Dette vil gøre adskillige kerneprogrammer utilgængelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette er sansynligvis forårsaget af et accelerator eller cache som Zend OPcache eller eAccelerator",
    "PHP modules have been installed, but they are still listed as missing?" : "Der er installeret PHP-moduler, men de fremstår stadig som fraværende?",
    "Please ask your server administrator to restart the web server." : "Du bedes anmode din serveradministrator om at genstarte webserveren.",
    "The required %s config variable is not configured in the config.php file." : "Den krævede config variabel %s er ikke konfigureret i config.php filen.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Du bedes anmode din serveradministrator om at kontrollere Nextcloud konfigurationen.",
    "Your data directory is readable by other people." : "Din datamappe kan læses af andre.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Ændr rettighederne til 0770, så mappen ikke kan listes af andre personer.",
    "Your data directory must be an absolute path." : "Datamappen skal have en absolut sti.",
    "Check the value of \"datadirectory\" in your configuration." : "Tjek værdien for \"datadictionary\" i din konfiguration.",
    "Your data directory is invalid." : "Datamappen er ugyldig.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Sørg for at der er en fil kaldet \" %1$s\" i roden af datafilen. Den bør have indholdet: \" %2$s\"",
    "Action \"%s\" not supported or implemented." : "Aktiviteten \"%s\" er ikke understøttet eller implementeret.",
    "Authentication failed, wrong token or provider ID given" : "Kunne ikke validere brugeren",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Anmodningen kunne ikke gennemføres pga. manglende parameter: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" already used by cloud sammenkoblingsleverandør \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud sammenkoblingsleverandør med ID: \"%s\" eksisterer ikke.",
    "Could not obtain lock type %d on \"%s\"." : "Kunne ikke opnå en låsetype %d på \"%s\".",
    "Storage unauthorized. %s" : "Lageret er ikke autoriseret. %s",
    "Storage incomplete configuration. %s" : "Lageret er ikke konfigureret korrekt. %s",
    "Storage connection error. %s" : "Forbindelses fejl til lageret. %s",
    "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
    "Storage connection timeout. %s" : "Lageret svarer ikke. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "For at tillade at denne kontrol køres så skal du sikre dig at din webserver kan forbinde til sig selv. Derfor skal den kunne opløse og forbinde til mindst en af dets `trusted_domains` eller `overwrite.cli.url`. Denne fejl kan være resultatet af en server-side DNS mismatch eller udadgående firewall regel.",
    "Transcribe audio" : "Transskriber lyd",
    "Transcribe the things said in an audio" : "Transskriber de ting, der siges i en lydfil",
    "Audio input" : "Lydinput",
    "The audio to transcribe" : "Lyden der skal transskriberes",
    "Transcription" : "Transskription",
    "The transcribed text" : "Den transskriberede tekst",
    "Chat with an agent" : "Chat med en agent",
    "Chat message" : "Chatbeskeder",
    "A chat message to send to the agent." : "En chatbesked til agenten.",
    "Confirmation" : "Bekræftelse",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Om tidligere forespurgte handlinger skal bekræftes: 0 for nægtelse og 1 for bekræftelse.",
    "Conversation token" : "Samtaletoken",
    "A token representing the conversation." : "Et token, som repræsenterer samtalen.",
    "Generated response" : "Genereret respons",
    "The response from the chat model." : "Svaret fra chatmodellen.",
    "The new conversation token" : "Det nye samtaletoken",
    "Send this along with the next interaction." : "Send dette sammen med den næste interaktion.",
    "Requested actions by the agent" : "Krævede handlinger af agenten",
    "Actions that the agent would like to carry out in JSON format." : "Handlinger, som agenten gerne vil udføre i JSON-format.",
    "Context write" : "Kontekstskrivning",
    "Writes text in a given style based on the provided source material." : "Skriver tekst i en given stil baseret på det medfølgende kildemateriale.",
    "Writing style" : "Skrivestil",
    "Demonstrate a writing style that you would like to immitate" : "Demonstrer en skrivestil, som du gerne vil efterligne",
    "Source material" : "Kildemateriale",
    "The content that would like to be rewritten in the new writing style" : "Indhold som skal genskrives i den nye skrivestil",
    "Generated text" : "Genereret tekst",
    "The generated text with content from the source material in the given style" : "Den genererede tekst med indhold fra kildematerialet i den givne stil",
    "Emoji generator" : "Emoji generator",
    "Takes text and generates a representative emoji for it." : "Tager tekst og genererer en repræsentativ emoji for det.",
    "The text to generate an emoji for" : "Teksten der skal genereres en emoji for",
    "Generated emoji" : "Genereret emoji",
    "The generated emoji based on the input text" : "Den genererede emoji baseret på inputteksten",
    "Generate image" : "Generer billede",
    "Generate an image from a text prompt" : "Generer et billede fra en tekstprompt",
    "Prompt" : "Prompt",
    "Describe the image you want to generate" : "Beskriv det billede du vil generere",
    "Number of images" : "Antal billeder",
    "How many images to generate" : "Hvor mange billeder skal genereres",
    "Output images" : "Output billeder",
    "The generated images" : "De genererede billeder",
    "Free text to text prompt" : "Fritekst til tekstprompt",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Kører en vilkårlig prompt gennem en sprogmodel, der returnerer et svar",
    "Describe a task that you want the assistant to do or ask a question" : "Beskriv en opgave, som du ønsker at assistenten udføre eller stil et spørgsmål",
    "Generated reply" : "Genereret svar",
    "The generated text from the assistant" : "Den genererede tekst fra assistenten",
    "Change Tone" : "Ændr tone",
    "Change the tone of a piece of text." : "Ændre tonen i et stykke tekst.",
    "Write a text that you want the assistant to rewrite in another tone." : "Skriv en tekst, som assistenten skal skrive i en anden tone.",
    "Desired tone" : "Ønsket tone",
    "In which tone should your text be rewritten?" : "I hvilken tone skal din tekst omskrives?",
    "The rewritten text in the desired tone, written by the assistant:" : "Den omskrevne tekst i den ønskede tone, skrevet af assistenten:",
    "Chat" : "cHAT",
    "Chat with the assistant" : "Chat med assistent",
    "System prompt" : "Systemprompt",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Definer regler og antagelser, som assistenten skal følge under samtalen.",
    "Chat history" : "Chathistorik",
    "The history of chat messages before the current message, starting with a message by the user" : "Historikken for chatbeskeder før den aktuelle besked, startende med en besked fra brugeren",
    "Response message" : "Svarmeddelelse",
    "The generated response as part of the conversation" : "Det genererede svar som en del af samtalen",
    "Chat with tools" : "Chat med værktøjer",
    "Chat with the language model with tool calling support." : "Chat med sprogmodellen med værktøj opkaldsunderstøttelse.",
    "Tool message" : "Værktøjsbesked",
    "The result of tool calls in the last interaction" : "Resultatet af værktøjsopkald i den sidste interaktion",
    "Available tools" : "Tilgængelige værktøjer",
    "The available tools in JSON format" : "De tilgængelige værktøjer i JSON format",
    "The response from the chat model" : "Svaret fra chatmodellen",
    "Tool calls" : "Værktøjsopkald",
    "Tools call instructions from the model in JSON format" : "Værktøjsopkald instruktioner fra modellen i JSON format",
    "Formalize text" : "Formaliser tekst",
    "Takes a text and makes it sound more formal" : "Anvender en tekst og får det til at lyde mere formelt",
    "Write a text that you want the assistant to formalize" : "Skriv en tekst som du vil have assistenten til at formalisere",
    "Formalized text" : "Formaliseret tekst",
    "The formalized text" : "Den formaliserede tekst",
    "Generate a headline" : "Generer en overskrift",
    "Generates a possible headline for a text." : "Genererer en mulig overskrift til en tekst.",
    "Original text" : "Oprindelig tekst",
    "The original text to generate a headline for" : "Den oprindelige tekst til at generere en overskrift for",
    "The generated headline" : "Den genererede overskrift",
    "Proofread" : "Korrekturlæsning",
    "Proofreads a text and lists corrections" : "Korrekturlæser en tekst og lister rettelser",
    "Text" : "Tekst",
    "The text to proofread" : "Teksten til korrekturlæsning",
    "Corrections" : "Rettelser",
    "The corrections that should be made in your text" : "De rettelser, der skal foretages i din tekst",
    "Reformulate text" : "Omformuler tekst",
    "Takes a text and reformulates it" : "Anvender en tekst og omformulerer den",
    "Write a text that you want the assistant to reformulate" : "Skriv en tekst som du vil have assistenten til at omformulere",
    "Reformulated text" : "Omformuleret tekst",
    "The reformulated text, written by the assistant" : "Den omformulerede tekst, skrevet af assistenten",
    "Simplify text" : "Forenkel tekst",
    "Takes a text and simplifies it" : "Anvender en tekst og forenkler den",
    "Write a text that you want the assistant to simplify" : "Skriv en tekst, som du vil have assistenten til at forenkle",
    "Simplified text" : "Forenklet tekst",
    "The simplified text" : "Den forenklede tekst",
    "Summarize" : "Opsummer",
    "Summarizes a text" : "Sammenfatter en tekst",
    "The original text to summarize" : "Den oprindelige tekst der skal sammenfattes",
    "Summary" : "Oversigt",
    "The generated summary" : "Det genererede sammendrag",
    "Extract topics" : "Uddrag emner",
    "Extracts topics from a text and outputs them separated by commas" : "Udtrækker emner fra en tekst og udskriver dem adskilt af kommaer",
    "The original text to extract topics from" : "Den oprindelige tekst til at udtrække emner fra",
    "Topics" : "Emner",
    "The list of extracted topics" : "Listen over udtrukne emner",
    "Translate" : "Oversæt",
    "Translate text from one language to another" : "Oversæt tekst fra et sprog til et andet",
    "Origin text" : "Oprindelig tekst",
    "The text to translate" : "Teksten der skal oversættes",
    "Origin language" : "Oprindelsessprog",
    "The language of the origin text" : "Det sprog, der anvendes i oprindelsesteksten",
    "Target language" : "Målsprog",
    "The desired language to translate the origin text in" : "Det ønskede sprog som oprindelsesteksten skal oversættes til",
    "Result" : "Resultat",
    "The translated text" : "Den oversatte tekst",
    "Free prompt" : "Gratis prompt",
    "Runs an arbitrary prompt through the language model." : "Kører en arbitrær prompt gennem sprogmodellen.",
    "Generate headline" : "Generer overskrift",
    "Summarizes text by reducing its length without losing key information." : "Opsummerer tekst ved at reducere dens længde uden at miste nøgleinformation.",
    "Extracts topics from a text and outputs them separated by commas." : "Uddrager emner fra en tekst og skriver dem adskilt af kommaer.",
    "Education Edition" : "Uddanelses Version",
    "File name is a reserved word" : "Filnavnet er et reserveret ord",
    "File name contains at least one invalid character" : "Filnavnet indeholder mindst et ugyldigt tegn",
    "File name is too long" : "Filnavnet er for langt",
    "Users" : "Brugere",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med dig og vil gerne tilføje:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med dig og vil gerne tilføje",
    "»%s« added a note to a file shared with you" : "»%s« tilføjede en note til en fil delt med dig",
    "Open »%s«" : "Åbn »%s«",
    "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med dig",
    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med dig",
    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
    "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
    "Cannot download file" : "Kan ikke downloade filen",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Du bedes sikre at filen \".ocdata\" befinder sig i roden af din datamappe."
},
"nplurals=2; plural=(n != 1);");
